---
layout: "github"
page_title: "GitHub: github_repository"
description: |-
  Manages GitHub repositories
---

# github_repository

This resource allows you to create and manage GitHub repositories.
